// -*- coding: utf-8 -*-
// Copyright (C) 2015, 2017 Laboratoire de Recherche et Développement
// de l'Epita.
//
// This file is part of Spot, a model checking library.
//
// Spot is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// Spot is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
// or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
// License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#pragma once

#include <spot/twa/twagraph.hh>

namespace spot
{
  /// \brief Remove useless acceptance sets
  ///
  /// If \a strip is true (the default), the remaining acceptance set
  /// numbers will be shifted down to reduce maximal number of
  /// acceptance sets used.
  SPOT_API twa_graph_ptr
  cleanup_acceptance_here(twa_graph_ptr aut, bool strip = true);

  /// \brief Remove useless acceptance sets
  SPOT_API twa_graph_ptr
  cleanup_acceptance(const_twa_graph_ptr aut);

  /// \brief Simplify an acceptance condition
  ///
  /// Remove useless acceptance sets.
  /// Merge identical sets.
  /// If some sets are complement to each other, might result in the
  /// simplification of some clause in the acceptance condition.
  SPOT_API twa_graph_ptr
  simplify_acceptance_here(twa_graph_ptr aut);

  /// \brief Simplify an acceptance condition
  SPOT_API twa_graph_ptr
  simplify_acceptance(const_twa_graph_ptr aut);
}
